#ifndef _TARGET_H
#define _TARGET_H

#include "session.h"

#define rr_SQL_INJECTION -50
#define rr_CMD_INJECTION -51

int send_file(t_session *session);
int execute_cgi(t_session *session);
int show_index(t_session *session);
int handle_options_request(t_session *session);
int handle_trace_request(t_session *session);
int handle_plugin(t_session *session);

#endif
